@@ -157,16 +157,16 @@ class BaseSphereFrequencyComposite(BaseFrequencyComposite):
         self.sphere.R_0 = value
 
     @property
-    def A(self) -> float:
-        """ Wrapper for :attr:`osaft.core.geometries.Sphere.A`
+    def area(self) -> float:
+        """ Wrapper for :attr:`osaft.core.geometries.Sphere.area`
         """
-        return self.sphere.A
+        return self.sphere.area
 
     @property
-    def V(self) -> float:
-        """ Wrapper for :attr:`osaft.core.geometries.Sphere.V`
+    def volume(self) -> float:
+        """ Wrapper for :attr:`osaft.core.geometries.Sphere.volume`
         """
-        return self.sphere.V
+        return self.sphere.volume
 
 
 if __name__ == '__main__':
