@@ -647,11 +647,13 @@ class BesselFunctions:
         :param z: argument of the function
         :param i: i-th derivative is computed
         """
+        if not i:
+            return cls.besselj(n, z)
         return cls._adaptive_derivative(cls.besselj, i, n, z)
 
     @classmethod
     def adaptive_derivative_bessely(
-            cls, n: int, z: complex, i: int,
+            cls, n: int, z: complex, i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Bessel function of the second kind of order `n`. The coefficients
@@ -661,11 +663,13 @@ class BesselFunctions:
         :param z: argument of the function
         :param i: i-th derivative is computed at runtime.
         """
+        if not i:
+            return cls.bessely(n, z)
         return cls._adaptive_derivative(cls.bessely, i, n, z)
 
     @classmethod
     def adaptive_derivative_hankelh1(
-            cls, n: int, z: complex, i: int,
+            cls, n: int, z: complex, i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Hankel function of order `n`. The coefficients for the derivative
@@ -675,11 +679,13 @@ class BesselFunctions:
         :param z: argument of the function
         :param i: i-th derivative is computed
         """
+        if not i:
+            return cls.hankelh1(n, z)
         return cls._adaptive_derivative(cls.hankelh1, i, n, z)
 
     @classmethod
     def adaptive_derivative_hankelh2(
-            cls, n: int, z: complex, i: int,
+            cls, n: int, z: complex, i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Hankel function of order `n`. The coefficients for the derivative
@@ -689,6 +695,8 @@ class BesselFunctions:
         :param z: argument of the function
         :param i: i-th derivative is computed
         """
+        if not i:
+            return cls.hankelh2(n, z)
         return cls._adaptive_derivative(cls.hankelh2, i, n, z)
 
     @classmethod
