@@ -45,6 +45,7 @@ class ScatteringFieldData(VelocityFieldData, ABC):
 
         self._u.is_computed_by(self._sol, self._grid, self._mode)
         self._w.is_computed_by(self._sol, self._grid, self._mode)
+
     # -------------------------------------------------------------------------
     # API
     # -------------------------------------------------------------------------
@@ -276,6 +277,7 @@ class FluidScatteringData(ScatteringFieldData):
     :param theta_max: end point for tangential plotting range
     :param res: resolution, if tuple (radial resolution, tangential resolution)
     """
+
     def __init__(
         self,
         sol: BaseScattering,
@@ -302,13 +304,79 @@ class FluidScatteringData(ScatteringFieldData):
             'incident field',
         )
 
+        self._vel_pot = ActiveVariable(
+            self._reset_complex_array, 'velocity potential',
+        )
+        self._pressure = ActiveVariable(
+            self._reset_complex_array, 'acoustic pressure',
+        )
+
         # Set links
         self._u.is_computed_by(self._scattered, self._incident)
         self._w.is_computed_by(self._scattered, self._incident)
+        self._vel_pot.is_computed_by(self._sol, self._grid, self._mode)
+        self._pressure.is_computed_by(self._sol, self._grid, self._mode)
     # -------------------------------------------------------------------------
     # API
     # -------------------------------------------------------------------------
 
+    def get_pressure(
+            self,
+            instantaneous: bool = True,
+            phase: float = 0,
+            mode: Optional[int] = None,
+            scattered: bool = True,
+            incident: bool = True,
+    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        """Returns the velocity potential
+
+        returns the coordinates of the points of the plotting grid `x`,
+        `y` and the magnitude of the pressure field at
+        these points
+
+        :param instantaneous: if ``True``, then instantaneous field
+        :param phase: phase angle
+        :param mode: mode of oscillation, if `None` superposition
+        :param scattered: option if scattering field is plotted
+        :param incident: option if incident field is plotted
+        """
+        self._mode.value = mode
+        self.scattered = scattered
+        self.incident = incident
+        if instantaneous:
+            pressure_inst = self.pressure * exp(-1j * phase)
+            return self.x, self.z, pressure_inst.real
+        else:
+            return self.x, self.z, np.abs(self.pressure)
+
+    def get_velocity_potential(
+            self,
+            instantaneous: bool = True,
+            phase: float = 0,
+            mode: Optional[int] = None,
+            scattered: bool = True,
+            incident: bool = True,
+    ) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+        """Returns the velocity potential
+
+        returns the coordinates of the points of the plotting grid `x`,
+        `y` and the magnitude of the velocity potential field at
+        these points
+
+        :param phase: phase angle
+        :param mode: mode of oscillation, if `None` superposition
+        :param scattered: option if scattering field is plotted
+        :param incident: option if incident field is plotted
+        """
+        self._mode.value = mode
+        self.scattered = scattered
+        self.incident = incident
+        if instantaneous:
+            vel_pot_inst = self.velocity_potential * exp(-1j * phase)
+            return self.x, self.z, vel_pot_inst.real
+        else:
+            return self.x, self.z, np.abs(self.velocity_potential)
+
     def get_velocity_magnitude(
             self,
             instantaneous: bool = True,
@@ -383,6 +451,17 @@ class FluidScatteringData(ScatteringFieldData):
     # -------------------------------------------------------------------------
     # Getters for Dependent Variables
     # -------------------------------------------------------------------------
+    @property
+    def velocity_potential(self) -> np.array:
+        if np.all(self._vel_pot.value == 0):
+            self._compute_velocity_potential()
+        return self._vel_pot.value
+
+    @property
+    def pressure(self) -> np.array:
+        if np.all(self._pressure.value == 0):
+            self._compute_pressure()
+        return self._pressure.value
 
     @property
     def scattered(self) -> bool:
@@ -412,6 +491,58 @@ class FluidScatteringData(ScatteringFieldData):
     def incident(self, value: bool) -> None:
         self._incident.value = value
 
+    def _compute_pressure(self) -> None:
+        """Compute the velocity data and store them in respective attributes
+
+        Scattering velocity field is computed on the polar grid and transformed
+        to Cartesian coordinates for plotting.
+        """
+        arr_r = self.grid.arr_r
+        arr_theta = self.grid.arr_theta
+
+        for index, theta in enumerate(arr_theta):
+
+            # Indexing
+            min_index = index * self.resolution
+            max_index = min_index + self.resolution
+
+            # Coordinates
+            xs, zs = s2c_coord(self.grid.arr_r, theta)
+            self._x.value[min_index:max_index] = xs
+            self._z.value[min_index:max_index] = zs
+
+            # Displacements Velocities
+            pressure = self.sol.pressure(
+                arr_r, theta, 0, self.scattered, self.incident, self.mode,
+            )
+            self._pressure.value[min_index:max_index] = pressure
+
+    def _compute_velocity_potential(self) -> None:
+        """Compute the velocity data and store them in respective attributes
+
+        Scattering velocity field is computed on the polar grid and transformed
+        to Cartesian coordinates for plotting.
+        """
+        arr_r = self.grid.arr_r
+        arr_theta = self.grid.arr_theta
+
+        for index, theta in enumerate(arr_theta):
+
+            # Indexing
+            min_index = index * self.resolution
+            max_index = min_index + self.resolution
+
+            # Coordinates
+            xs, zs = s2c_coord(self.grid.arr_r, theta)
+            self._x.value[min_index:max_index] = xs
+            self._z.value[min_index:max_index] = zs
+
+            # Displacements Velocities
+            vel_pot = self.sol.velocity_potential(
+                arr_r, theta, 0, self.scattered, self.incident, self.mode,
+            )
+            self._vel_pot.value[min_index:max_index] = vel_pot
+
     # -------------------------------------------------------------------------
     # Private Methods
     # -------------------------------------------------------------------------
