@@ -123,6 +123,103 @@ class BaseScattering(ABC):
 
         return out
 
+    def pressure(
+        self,
+        r: Union[float, Sequence],
+        theta: Union[float, Sequence],
+        t: Union[float, Sequence],
+        scattered: bool,
+        incident: bool,
+        mode: Optional[int] = None,
+    ) -> complex:
+        """ Returns the acoustic pressure [Pa].
+
+        :param r: radial coordinate [m]
+        :param theta: tangential coordinate [rad]
+        :param t: time [s]
+        :param scattered: add scattered field
+        :param incident: add incident
+        :param mode: specific mode number of interest; if `None` then all
+                     modes until :attr:`.N_max`
+        """
+        r, theta, t = InputHandler.handle_input(
+            r,
+            theta,
+            t,
+            self.R_0,
+            inside_sphere=False,
+        )
+
+        out = -1j * self.omega * self.rho_f
+        out *= self.velocity_potential(r, theta, t, scattered, incident, mode)
+
+        return out
+
+    @abstractmethod
+    def potential_coefficient(self, n: int) -> complex:
+        """ Wrapper to the fluid scattering coefficients for an inviscid fluid
+
+        This method must be implemented by every theory to have a common
+        interface for other modules.
+
+        :param n: mode
+        """
+        pass
+
+    def velocity_potential(
+        self,
+        r: Union[float, Sequence],
+        theta: Union[float, Sequence],
+        t: Union[float, Sequence],
+        scattered: bool,
+        incident: bool,
+        mode: Optional[int] = None,
+    ) -> complex:
+        """ Returns the velocity potential of the fluid in [m^2/s].
+
+        :param r: radial coordinate [m]
+        :param theta: tangential coordinate [rad]
+        :param t: time [s]
+        :param scattered: add scattered field
+        :param incident: add incident
+        :param mode: specific mode number of interest; if `None` then all
+                     modes until :attr:`.N_max`
+        """
+        r, theta, t = InputHandler.handle_input(
+            r,
+            theta,
+            t,
+            self.R_0,
+            inside_sphere=False,
+        )
+
+        if not scattered and not incident:
+            raise ValueError(
+                'Neither scattered nor incident field has '
+                'been has been selected. Velocity field is zero.', )
+        elif scattered and incident:
+            def inner_func(n: int, r: float):
+                x = self.k_f * r
+                out = self.field.A_in(n) * Bf.besselj(n, x)
+                out += self.potential_coefficient(n) * Bf.hankelh1(n, x)
+                return out
+        elif scattered and not incident:
+            def inner_func(n: int, r: float):
+                x = self.k_f * r
+                return self.potential_coefficient(n) * Bf.hankelh1(n, x)
+        else:
+            def inner_func(n: int, r: float):
+                x = self.k_f * r
+                return self.field.A_in(n) * Bf.besselj(n, x)
+
+        if mode is None:
+            out = self.radial_mode_superposition(inner_func, r, theta, t, mode)
+        else:
+            out = Leg.cos_monomial(mode, theta, inner_func(mode, r))
+            out *= exp(-1j * self.omega * t)
+
+        return out
+
     @abstractmethod
     def radial_particle_velocity(
         self,
@@ -256,7 +353,14 @@ class BaseScattering(ABC):
 
 
         where :math:`f_\\text{n}(r)` is the ``radial_func(n, r)``
-        passed to the method.
+        passsed to the method.
+
+        :param radial_func: radial function dependent on :attr:`r`
+        :param r: radial coordinate [m]
+        :param theta: tangential coordinate [rad]
+        :param t: time [s]
+        :param mode: specific mode number of interest; if `None` then all
+                     modes until :attr:`.N_max`
         """
 
         out = exp(-1j * self.omega * t)
@@ -273,7 +377,7 @@ class BaseScattering(ABC):
 
     def tangential_mode_superposition(
         self,
-        radial_func: Callable[[int, float], complex],
+        tangential_func: Callable[[int, float], complex],
         r: Union[float, Sequence],
         theta: Union[float, Sequence],
         t: Union[float, Sequence],
@@ -297,8 +401,15 @@ class BaseScattering(ABC):
            \\,P^1_n(\\cos\\theta)
 
 
-        where :math:`f_n(r)` is the ``radial_func(n, r)``
-        passed to the method.
+        where :math:`f_n(r)` is the ``tangential_func(n, r)``
+        passsed to the method.
+
+        :param tangential_func: tangential function dependent on :attr:`r`
+        :param r: radial coordinate [m]
+        :param theta: tangential coordinate [rad]
+        :param t: time [s]
+        :param mode: specific mode number of interest; if `None` then all
+                     modes until :attr:`.N_max`
         """
 
         out = exp(-1j * self.omega * t)
@@ -306,13 +417,13 @@ class BaseScattering(ABC):
             out *= Leg.first_cos_monomial(
                 mode,
                 theta,
-                radial_func(mode, r),
+                tangential_func(mode, r),
             )
         else:
             out *= Leg.first_cos_poly(
                 theta,
                 np.array(
-                    [radial_func(n, r) for n in full_range(0, self.N_max)],
+                    [tangential_func(n, r) for n in full_range(0, self.N_max)],
                 ),
             )
         return out
