@@ -2,9 +2,12 @@ from __future__ import annotations
 
 from typing import Optional, Union
 
+import numpy as np
+
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
 from osaft.core.geometries import Sphere
+from osaft.core.warnings import EPS, raise_assumption_warning
 from osaft.solutions.doinikov1994compressible.arf_general import (
     ARFArbitraryRadius,
 )
@@ -79,20 +82,30 @@ class ARF(ARFArbitraryRadius):
         It logs the current values of :attr:`x` and :attr:`x_v`.
 
         :raises WrongWaveTypeError: if wrong :attr:`wave_type`
+        :raises AssumptionWarning: if used solution might not be valid
         """
 
         # Checking Wave Type
         self.check_wave_type()
+
+        # Checking x_v and x
+        abs_x = np.abs(self.x)
+        abs_x_v = np.abs(self.x_v)
+
         # Cases
         if self.small_boundary_layer and (
             not
             self.large_boundary_layer
         ):
+            test = abs_x < EPS and 1 < EPS * abs_x_v
+            raise_assumption_warning(test)
             return self._arf_small_particle_small_delta()
         elif (
                 not self.small_boundary_layer and
                 self.large_boundary_layer
         ):
+            test = abs_x < EPS * abs_x_v and abs_x_v < EPS
+            raise_assumption_warning(test)
             return self._arf_small_particle_large_delta()
         elif (
                 not self.small_boundary_layer and
