@@ -4,7 +4,7 @@ import numpy as np
 
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
-from osaft.core.functions import SpecialFunctions as Sp
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.geometries import Sphere
 from osaft.core.helper import InputHandler
 from osaft.core.variable import ActiveListVariable
@@ -20,18 +20,18 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
     """Scattering field of Doinikov (viscous fluid-viscous sphere; 1994)
 
     :param f: Frequency [Hz]
-    :param R_0: Radius of the solid [m]
-    :param rho_s: Density of the fluid-like solid [kg/m^3]
-    :param c_s: Speed of sound of the sphere [m/s]
-    :param eta_s: shear viscosity of the sphere [Pa s]
-    :param zeta_s: bulk viscosity of the sphere [Pa s]
+    :param R_0: Radius of the sphere [m]
+    :param rho_s: Density of the sphere [kg/m^3]
+    :param c_s: Speed of sound of in the sphere [m/s]
+    :param eta_s: shear viscosity of in the sphere  [Pa s]
+    :param zeta_s: bulk viscosity of in the sphere [Pa s]
     :param rho_f: Density of the fluid [kg/m^3]
     :param c_f: Speed of sound of the fluid [m/s]
     :param eta_f: shear viscosity [Pa s]
     :param zeta_f: bulk viscosity [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
     :param position: Position within the standing wave field [m]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     :param N_max: Highest order mode included in the computation [-]
     """
 
@@ -101,35 +101,28 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
         # computation according to (3.13), (3.14) and (3.20)
         if n == 0:
             tmp1 = 4 * (self.eta_f - self.eta_s) * self.x * self.x_hat
-            tmp1 *= Sp.besselj(1, self.x_hat)
+            tmp1 *= Bf.besselj(1, self.x_hat)
 
             tmp2 = 1j * self.omega * self.R_0**2
 
             # numerator
             num = self.rho_f * self.x_hat
-            num *= Sp.besselj(0, self.x) * Sp.besselj(1, self.x_hat)
-
+            num *= Bf.besselj(0, self.x) * Bf.besselj(1, self.x_hat)
             num -= self.rho_s * self.x * (
-                Sp.besselj(1, self.x) *
-                Sp.besselj(0, self.x_hat)
+                Bf.besselj(1, self.x) *
+                Bf.besselj(0, self.x_hat)
             )
-
             num *= tmp2
-
-            num -= tmp1 * Sp.besselj(1, self.x)
+            num -= tmp1 * Bf.besselj(1, self.x)
 
             # denominator
             den = self.rho_s * self.x
-            den *= Sp.hankelh1(1, self.x) * Sp.besselj(0, self.x_hat)
-
+            den *= Bf.hankelh1(1, self.x) * Bf.besselj(0, self.x_hat)
             den -= self.rho_f * self.x_hat * (
-                Sp.hankelh1(0, self.x) *
-                Sp.besselj(1, self.x_hat)
+                Bf.hankelh1(0, self.x) * Bf.besselj(1, self.x_hat)
             )
-
             den *= tmp2
-
-            den += tmp1 * Sp.hankelh1(1, self.x)
+            den += tmp1 * Bf.hankelh1(1, self.x)
 
             new_value = num / den
         else:
@@ -170,27 +163,22 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
             tmp2 = 1j * self.omega * self.R_0**2
 
             # numerator
-            num = Sp.besselj(0, self.x) * Sp.hankelh1(1, self.x)
+            num = Bf.besselj(0, self.x) * Bf.hankelh1(1, self.x)
 
-            num -= Sp.besselj(1, self.x) * Sp.hankelh1(0, self.x)
+            num -= Bf.besselj(1, self.x) * Bf.hankelh1(0, self.x)
 
             num *= tmp2 * self.x * self.rho_f
 
             # denominator
             den = self.rho_s * self.x
-            den *= Sp.hankelh1(1, self.x) * Sp.besselj(0, self.x_hat)
+            den *= Bf.hankelh1(1, self.x) * Bf.besselj(0, self.x_hat)
 
             den -= self.rho_f * self.x_hat * (
-                Sp.hankelh1(0, self.x) *
-                Sp.besselj(1, self.x_hat)
+                Bf.hankelh1(0, self.x) *
+                Bf.besselj(1, self.x_hat)
             )
-
             den *= tmp2
-
-            den += tmp1 * (
-                Sp.hankelh1(1, self.x) *
-                Sp.besselj(1, self.x_hat)
-            )
+            den += tmp1 * (Bf.hankelh1(1, self.x) * Bf.besselj(1, self.x_hat))
 
             new_value = num / den
         else:
@@ -230,8 +218,8 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
         :param t: time [s]
-        :param mode: specific modenumber of interest; if `None` then all
-                     modes until :attr:`.N_max`
+        :param mode: mode to be plotted, if `None` then sum of all mode up
+                     to `N_max`
         """
         r, theta, t = InputHandler.handle_input(
             r, theta, t, self.R_0,
@@ -240,19 +228,17 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
 
         def radial_velocity(n: int, r: float) -> complex:
             out = self.k_s * self.alpha_hat_n(n)
-            out *= Sp.d1_besselj(n, r * self.k_s)
+            out *= Bf.d1_besselj(n, r * self.k_s)
 
             arg = r * self.k_vs
-            out -= n * (n + 1) / r * self.beta_hat_n(n) * Sp.besselj(n, arg)
+            out -= n * (n + 1) / r * self.beta_hat_n(n) * Bf.besselj(n, arg)
             out *= self.A_in(n)
             return out
 
-        out = self.radial_mode_superposition(
+        return self.radial_mode_superposition(
             radial_velocity, r, theta, t, mode,
         )
 
-        return out
-
     def tangential_particle_velocity(
             self,
             r: Union[float, np.ndarray, list[float]],
@@ -268,8 +254,8 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
         :param t: time [s]
-        :param mode: specific modenumber of interest; if `None` then all
-                     modes until :attr:`.N_max`
+        :param mode: mode to be plotted, if `None` then sum of all mode up
+                     to `N_max`
         """
         r, theta, t = InputHandler.handle_input(
             r, theta, t, self.R_0,
@@ -277,19 +263,17 @@ class ScatteringField(CoefficientMatrix, BaseScatteringDoinikov1994):
         )
 
         def tangential_velocity(n: int, r: float) -> complex:
-            out = Sp.besselj(n, self.k_vs * r)
-            out += r * self.k_vs * Sp.d1_besselj(n, self.k_vs * r)
+            out = Bf.besselj(n, self.k_vs * r)
+            out += r * self.k_vs * Bf.d1_besselj(n, self.k_vs * r)
             out *= -self.beta_hat_n(n)
-            out += self.alpha_hat_n(n) * Sp.besselj(n, self.k_s * r)
+            out += self.alpha_hat_n(n) * Bf.besselj(n, self.k_s * r)
             out *= self.A_in(n) / r
             return out
 
-        out = self.tangential_mode_superposition(
+        return self.tangential_mode_superposition(
             tangential_velocity, r, theta, t, mode,
         )
 
-        return out
-
 
 if __name__ == '__main__':
     pass
