@@ -154,11 +154,11 @@ class ChangingNumber(BaseChangingVariable):
         high: Union[None, int, float],
     ):
         if low is not None and high is not None:
-            assert low < value < high, 'condition low < value < high not met'
+            assert low <= value <= high, 'condition low < value < high not met'
         elif low is not None:
-            assert low < value, 'condition low < value < high is not met'
+            assert low <= value, 'condition low < value < high is not met'
         elif high is not None:
-            assert value < high, 'condition low < value < high is not met'
+            assert value <= high, 'condition low < value < high is not met'
 
     @property
     def low(self) -> Union[None, int, float]:
@@ -379,8 +379,11 @@ class BaseTest(NumericTestCase):
         self._eta_s = ChangingFloat('eta_s', 1e-3, self.seed, low=0)
         self._zeta_s = ChangingFloat('zeta_s', 1e-3, self.seed, low=0)
         # Viscous Fluid
-        self._eta_f = ChangingFloat('eta_f', 1e-2, self.seed, low=1e-6)
-        self._zeta_f = ChangingFloat('zeta_f', 1e-2, self.seed, low=0)
+        self._eta_f = ChangingFloat(
+            'eta_f', 1e-3, self.seed, low=1e-5,
+            high=1e-2,
+        )
+        self._zeta_f = ChangingFloat('zeta_f', 1e-3, self.seed, low=0)
         # Viscoelastic Fluid
         self._eta_p = ChangingFloat('eta_p', 1e-3, self.seed, low=0)
         self._zeta_p = ChangingFloat('zeta_p', 1e-3, self.seed, low=0)
@@ -400,6 +403,11 @@ class BaseTest(NumericTestCase):
             WaveType, self.seed,
         )
 
+        self._N_max = ChangingInt(
+            'N_max', 2, self.seed,
+            low=2, high=5,
+        )
+
         self.test_variables = {
             # Geometry
             self._R_0,
@@ -427,6 +435,8 @@ class BaseTest(NumericTestCase):
             self._p_0,
             self._position,
             self._wave_type,
+            # Number of Modes
+            self._N_max,
         }
 
         # Frequency Class
@@ -524,7 +534,7 @@ class BaseTest(NumericTestCase):
         for method, args in dict_of_methods.items():
             func_1 = getattr(self, method)
             func_2 = getattr(self.cls, method)
-            for n in reversed(np.arange(n_end)):
+            for n in range(n_end, 0, -1):
 
                 if args is not None:
                     if isinstance(args, tuple):
@@ -689,6 +699,14 @@ class BaseTest(NumericTestCase):
     def wave_type(self, value: WaveType) -> None:
         self._wave_type.value = value
 
+    @property
+    def N_max(self):
+        return self._N_max.value
+
+    @N_max.setter
+    def N_max(self, value: int):
+        self._N_max.value = value
+
     # -----------------------------------------------------------------------------
     # Tests
     # -----------------------------------------------------------------------------
